
/**
 * Dependencies
 */
var _       = require('lodash');
var fs      = require('vinyl-fs');
var map     = require('map-stream');
var path    = require('path');
var q       = require('q');

/**
 * Local dependencies
 */
var mm = require('./mightymite');
var tpl = require('./templates');
var util = require('./utilities');

/**
 * Build page templates and output to
 * destination directory
 */
module.exports.init = function() {

    var def = q.defer();

    // Grab everything in the pages directory
    var src = path.resolve(mm.config.pagesDir, '**/{.*,*.*}');

    fs.src(src)
        .pipe(map(function(file, callback) {

            // Compile template files only
            if (util.isTemplate(file)) {

                var root = util.getRoot(file, mm.config.pagesDir);

                file.contents = new Buffer(tpl.compile({
                    path: file.path,
                    contents: String(file.contents)
                }, {
                    root: root
                }));

                // Resolve path (files are put in a folder with the
                // filename, and renamed index).
                file.path = util.resolvePath(file);
            }

            // All other files pass through
            callback(null, file);
        }))
        .pipe(fs.dest(mm.config.dstDir))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};
